@@ -27,7 +27,10 @@ DISPLAYNAME = "displayName"
 
 
 def _MakeEventTraitMap(traits: Mapping[str, Any]) -> Dict[str, Any]:
-    if camera_traits.CameraEventImageTrait.NAME not in traits:
+    if (
+        camera_traits.CameraEventImageTrait.NAME not in traits
+        and camera_traits.CameraClipPreviewTrait.NAME not in traits
+    ):
         return {}
     event_trait_map: Dict[str, Any] = {}
     for (trait_name, trait) in traits.items():
@@ -70,7 +73,7 @@ class Device:
         return cast_assert(str, self._raw_data[DEVICE_NAME])
 
     @property
-    def type(self) -> Optional[str]:
+    def type(self) -> str:
         """Type of device for display purposes.
 
         The device type should not be used to deduce or infer functionality of
